#
# spec file for package python-kubernetes
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-kubernetes
Version:        8.0.1
Release:        3.5.1
Summary:        Kubernetes python client
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/kubernetes-incubator/client-python
Source:         https://files.pythonhosted.org/packages/source/k/kubernetes/kubernetes-%{version}.tar.gz
Patch0:         base64-padding-fix.patch
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module adal}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module google-auth}
BuildRequires:  %{python_module oauth2client}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module requests-oauthlib}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module urllib3}
BuildRequires:  %{python_module websocket-client}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%ifpython2
BuildRequires:  python2-ipaddress
Requires:       python-ipaddress >= 1.0.17
%endif
# Test
BuildRequires:  %{python_module autopep8}
BuildRequires:  %{python_module codecov}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module isort}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pluggy}
BuildRequires:  %{python_module pycodestyle}
BuildRequires:  %{python_module pytest}
# gh#kubernetes-client/python#749
# BuildRequires:  %%{python_module randomize}
BuildRequires:  %{python_module recommonmark}
# Documentation
BuildRequires:  %{python_module Sphinx}
Requires:       python-PyYAML >= 3.12
Requires:       python-adal
Requires:       python-certifi
Requires:       python-google-auth >= 1.0.1
Requires:       python-oauth2client
Requires:       python-python-dateutil >= 2.5.3
Requires:       python-requests
Requires:       python-requests-oauthlib
Requires:       python-setuptools
Requires:       python-six >= 1.9.0
Requires:       python-urllib3 >= 1.19.1
Requires:       python-websocket-client >= 0.32.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%python_subpackages

%description
Python client for kubernetes http://kubernetes.io/

%prep
%setup -q -n kubernetes-%{version}
%patch0 -p0

%build
%python_build

%install
%python_install
%fdupes %{buildroot}%{_prefix}

%check
%python_exec %{_bindir}/nosetests -v --cover-package=kubernetes.config,kubernetes.watch --cover-tests

%files %{python_files}
%defattr(-,root,root,-)
%{python_sitelib}/*

%changelog
* Tue Oct  8 2019 cbbayburt@suse.com
- python-ipaddress is only required for building on Python2
  (on Python3 is part of the standard library)
- Backport fix for base64 padding in kubeconfig (bsc#1151481)
  https://github.com/kubernetes-client/python-base/issues/65
- Added:
  * base64-padding-fix.patch
* Thu Feb  7 2019 toddrme2178@gmail.com
- Update to version 8.0.1
  + Bug Fix:
  - Refresh GCP auth tokens on API retrieval
  - Fix kubeconfig loading failure when server uri contains trailing slash
  + Security Fix:
  - Bump urllib3 version to pick up security fix for CVE-2018-20060
- Update to version 8.0.0
  + New Feature:
  - Add utility to create API resource from yaml file
- Update to version 8.0.0b1
  + Bug Fix:
  - Update ExecProvider to use safe\_get() to tolerate kube-config file that sets
  `args: null` and `env: null`
  - Properly deserialize API server's response when posting a deployment rollback
  + API Change:
  - dry-run: CREATE/UPDATE/PATCH methods now support dryRun parameter
- Update to version 8.0.0a1
  + New Feature:
  - Add exec-plugins support in kubeconfig
  + Bug Fix:
  - Fix reading kubeconfig data with bytes in Python 3
  + API Change:
  - Upon receiving a LIST request with expired continue token, the apiserver now returns a continue token together with the 410 "the from parameter is too old " error. If the client does not care about getting a list from a consistent snapshot, the client can use this token to continue listing from the next key, but the returned chunk will be from the latest snapshot
  - Introduces autoscaling/v2beta2 and custom\_metrics/v1beta2, which implement metric selectors for Object and Pods metrics, as well as allowing AverageValue targets on Objects, similar to External metrics
  - Create "coordination.k8s.io" api group with "Lease" api in it
  - Added support to restore a volume from a volume snapshot data source: adds TypedLocalObjectReference in the core API and adds DataSource in PersistentVolumeClaimSpec
  - ProcMount added to SecurityContext and AllowedProcMounts added to
    PodSecurityPolicy to allow paths in the container's /proc to not be masked
  - Support both directory and block device for local volume plugin FileSystem
    VolumeMode
  - SCTP is now supported as additional protocol (alpha) alongside TCP and UDP in
    Pod, Service, Endpoint, and NetworkPolicy
  - RuntimeClass is a new API resource for defining different classes of runtimes
    that may be used to run containers in the cluster. Pods can select a
    RunitmeClass to use via the RuntimeClassName field. This feature is in alpha,
    and the RuntimeClass feature gate must be enabled in order to use it
  - The PodShareProcessNamespace feature to configure PID namespace sharing within
    a pod has been promoted to beta
  - To address the possibility dry-run requests overwhelming admission webhooks that rely on side effects and a reconciliation mechanism, a new field is being added to admissionregistration.k8s.io/v1beta1.ValidatingWebhookConfiguration and admissionregistration.k8s.io/v1beta1.MutatingWebhookConfiguration so that webhooks can explicitly register as having dry-run support. If a dry-run request is made on a resource that triggers a non dry-run supporting webhook, the request will be completely rejected, with "400: Bad Request". Additionally, a new field is being added to the admission.k8s.io/v1beta1.AdmissionReview API object, exposing to webhooks whether or not the request being reviewed is a dry-run
  - Add custom object status and scale api
  - dry-run: DELETE operations now support dryRun parameter
  - Default extensions/v1beta1 Deployment's ProgressDeadlineSeconds to MaxInt32
- Update to version 7.0.0
  + New Features:
  - Add support for refreshing Azure tokens
- Update to version 7.0.0b1
  + New Features:
  - Add Azure support to authentication loading
- Update to version 7.0.0a1
  + Breaking Change:
  - **ACTION REQUIRED** Rename the currently being-used `async` parameter to `async_req` to support Python 3.7 because it's a reserved keyword in Python 3.7
  + Bug Fix:
  - Watch now properly deserializes custom resource objects and updates resource version
  - `idp-certificate-authority-data` in kubeconfig is now optional instead of required for OIDC token refresh
  + API Change:
  - ApiextensionsV1beta1Api: Add PATCH and GET to custom_resource_definition_status
  - ApiregistrationV1Api and ApiregistrationV1beta1Api: Add PATCH and GET to api_service_status
  - CertificatesV1beta1Api: Add PATCH and GET to certificate_signing_request_status
  - SchedulingV1beta1Api: Promote priority_class to beta
  - PodSecurityPolicy now supports restricting hostPath volume mounts to be readOnly and under specific path prefixes
  - The Sysctls experimental feature has been promoted to beta (enabled by default via the `Sysctls` feature flag). PodSecurityPolicy and Pod objects now have fields for specifying and controlling sysctls. Alpha sysctl annotations will be ignored by 1.11+ kubelets. All alpha sysctl annotations in existing deployments must be converted to API fields to be effective.
  - Add CRD Versioning with NOP converter
  - Volume topology aware dynamic provisioning
  - Fixed incorrect OpenAPI schema for CustomResourceDefinition objects with a validation schema
- Update to version 6.0.0
  - Config loader now supports OIDC auth
  - Bug fix: fix expiry time checking in API token refresh
- Update to version 6.0.0b1
  - Update to Kubernetes 1.10 cluster
  - Config loader now raises exception on duplicated name in kubeconfig
  + API change:
  - CustomObjectsApi: Add PATCH to CustomObjectsApi
  - Promoting the apiregistration.k8s.io (aggregation) to GA (ApiregistrationV1Api)
  - CoreV1Api: remove /proxy legacy API (deprecated since kubernetes v1.2). Use the /proxy subresources on objects that support HTTP proxying
  - The `PodSecurityPolicy` API has been moved to the `policy/v1beta1` API group. The `PodSecurityPolicy` API in the `extensions/v1beta1` API group is deprecated and will be removed in a future release. Authorizations for using pod security policy resources should change to reference the `policy` API group after upgrading to 1.11
  - StorageV1beta1Api: Introduce new `VolumeAttachment` API Object
  - V1FlexPersistentVolumeSource: PersistentVolume flexVolume sources can now reference secrets in a namespace other than the PersistentVolumeClaim's namespace
  - ACTION REQUIRED: VolumeScheduling and LocalPersistentVolume features are beta and enabled by default.  The PersistentVolume NodeAffinity alpha annotation is deprecated and will be removed in a future release
  - Allows HorizontalPodAutoscaler to use global metrics not associated with any Kubernetes object (for example metrics from a hoster service running outside of Kubernetes cluster)
  - v1.Pod now has a field to configure whether a single process namespace should be shared between all containers in a pod. This feature is in alpha preview.
  - delete_namespaced_service() now takes an required body (delete option) parameter. Refactor service storage to remove registry wrapper
  + Documentation update:
  - Never let cluster-scoped resources skip webhooks
  - Clarify that ListOptions.Timeout is not conditional on inactivity
  - Indicate endpoint subsets are an optional field
* Thu Feb  7 2019 mcepl@suse.com
- update to 8.0.1:
    too many changes to record here, see
    https://github.com/kubernetes-client/python/blob/master/CHANGELOG.md
    for complete list.
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Tue Mar 27 2018 tbechtold@suse.com
- update to 5.0.0:
  - Update to Kubernetes 1.9 cluster
  - Label selector for pods is now required and must match the pod template's
    labels for v1beta2 StatefulSetSpec, ReplicaSetSpec, DaemonSetSpec and
    DeploymentSpec kubernetes/kubernetes#55357
  - The dynamic admission webhook is split into two kinds, mutating and
    validating. The kinds have changed completely and old code must be ported to
    admissionregistration.k8s.io/v1beta1 - MutatingWebhookConfiguration and
    ValidatingWebhookConfiguration kubernetes/kubernetes#55282
  - DaemonSet, Deployment, ReplicaSet, and StatefulSet have been promoted to GA
    and are available in the apps/v1 group version kubernetes/kubernetes#53679
  - Introduce new storage.k8s.io/v1alpha1 VolumeAttachment object
    kubernetes/kubernetes#54463
  - Introduce core/v1 RBDPersistentVolumeSource kubernetes/kubernetes#54302
  - StatefulSet status now has support for conditions
    kubernetes/kubernetes#55268
  - DaemonSet status now has support for conditions kubernetes/kubernetes#55272
* Tue Feb 13 2018 tbechtold@suse.com
- update to 4.0.0:
  - api change V1PersistentVolumeSpec to V1ScaleIOPersistentVolumeSource #397.
  - Make sure PyPI source distribution is complete with all files from the
    root directory
  - Update to Kubernetes 1.8 cluster
  - IntOrString is now object thus it can be int or string. #18 #359
  - Adding stream package to support calls like exec. The old way of calling
    them is deprecated. See README.md#why-execattach-calls-doesnt-work.
  - config.http_proxy_url is deprecated. use configuration.proxy instead.
  - Configuration is not a singleton object anymore. Please use
    Configuraion.set_default to change default configuration.
  - Configuration class does not support `ws_streaming_protocol` anymore. In
    ApiClient.set_default_header set `sec-websocket-protocol` to the preferred
    websocket protocol.
  - Fix Operation names for subresources kubernetes/kubernetes#49357
  - Add proper GCP config loader and refresher kubernetes-client/python-base#22
  - Add ws_streaming_protocol and use v4 by default
    kubernetes-client/python-base#20
  - Respect the KUBECONFIG environment variable if set
    kubernetes-client/python-base#19
  - Allow setting maxsize for PoolManager kubernetes-client/python-base#18
  - Restricting the websocket-client to <=0.40 #299
  - Update client to kubernetes 1.7
  - Support ThirdPartyResources (TPR) and CustomResourceDefinitions (CRD).
    Note that TPR is deprecated in kubernetes #251 #201
  - Better dependency management #136
  - Add support for python3.6 #244
- Adjust Requires and BuildRequires
- Fix Source url
* Thu Aug 17 2017 dmueller@suse.com
- small buildrequires cleanup
* Wed Jun 28 2017 mc@suse.com
- initial release 2.0.0
